@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2001 Hewlett-Packard, Matthew Wilcox
+ * Copyright (c) 2001-2017 The strace developers.
  */
 
 [  0] = { 0,	0,		SEN(restart_syscall),		"restart_syscall"	},
@@ -20,7 +21,7 @@
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown),			"lchown"		},
 [ 17] = { 3,	TN,		SEN(socket),			"socket"		},
-[ 18] = { 2,	TF,		SEN(stat),			"stat"			},
+[ 18] = { 2,	TF|TST|TSTA,	SEN(stat),			"stat"			},
 [ 19] = { 3,	TD,		SEN(lseek),			"lseek"			},
 [ 20] = { 0,	NF,		SEN(getpid),			"getpid"		},
 [ 21] = { 5,	TF,		SEN(mount),			"mount"			},
@@ -30,7 +31,7 @@
 [ 25] = { 1,	0,		SEN(stime),			"stime"			},
 [ 26] = { 4,	0,		SEN(ptrace),			"ptrace"		},
 [ 27] = { 1,	0,		SEN(alarm),			"alarm"			},
-[ 28] = { 2,	TD,		SEN(fstat),			"fstat"			},
+[ 28] = { 2,	TD|TFST|TSTA,	SEN(fstat),			"fstat"			},
 [ 29] = { 0,	TS,		SEN(pause),			"pause"			},
 [ 30] = { 2,	TF,		SEN(utime),			"utime"			},
 [ 31] = { 3,	TN,		SEN(connect),			"connect"		},
@@ -64,14 +65,14 @@
 [ 59] = { 1,	0,		SEN(uname),			"uname"			},
 [ 60] = { 1,	NF,		SEN(umask),			"umask"			},
 [ 61] = { 1,	TF,		SEN(chroot),			"chroot"		},
-[ 62] = { 2,	0,		SEN(ustat),			"ustat"			},
+[ 62] = { 2,	TSFA,		SEN(ustat),			"ustat"			},
 [ 63] = { 2,	TD,		SEN(dup2),			"dup2"			},
 [ 64] = { 0,	NF,		SEN(getppid),			"getppid"		},
 [ 65] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
 [ 66] = { 0,	0,		SEN(setsid),			"setsid"		},
 [ 67] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
-[ 68] = { 0,	TS,		SEN(siggetmask),		"sgetmask"		},
-[ 69] = { 1,	TS,		SEN(sigsetmask),		"ssetmask"		},
+[ 68] = { 0,	TS,		SEN(sgetmask),			"sgetmask"		},
+[ 69] = { 1,	TS,		SEN(ssetmask),			"ssetmask"		},
 [ 70] = { 2,	0,		SEN(setreuid),			"setreuid"		},
 [ 71] = { 2,	0,		SEN(setregid),			"setregid"		},
 [ 72] = { 3,	TM,		SEN(mincore),			"mincore"		},
@@ -86,7 +87,7 @@
 [ 81] = { 2,	0,		SEN(setgroups),			"setgroups"		},
 [ 82] = { 6,	TN,		SEN(sendto),			"sendto"		},
 [ 83] = { 2,	TF,		SEN(symlink),			"symlink"		},
-[ 84] = { 2,	TF,		SEN(lstat),			"lstat"			},
+[ 84] = { 2,	TF|TLST|TSTA,	SEN(lstat),			"lstat"			},
 [ 85] = { 3,	TF,		SEN(readlink),			"readlink"		},
 [ 86] = { 1,	TF,		SEN(uselib),			"uselib"		},
 [ 87] = { 2,	TF,		SEN(swapon),			"swapon"		},
@@ -101,9 +102,9 @@
 [ 96] = { 2,	0,		SEN(getpriority),		"getpriority"		},
 [ 97] = { 3,	0,		SEN(setpriority),		"setpriority"		},
 [ 98] = { 4,	TN,		SEN(recv),			"recv"			},
-[ 99] = { 2,	TF,		SEN(statfs),			"statfs"		},
-[100] = { 2,	TD,		SEN(fstatfs),			"fstatfs"		},
-[101] = { 2,	TF,		SEN(stat64),			"stat64"		},
+[ 99] = { 2,	TF|TSF|TSFA,	SEN(statfs),			"statfs"		},
+[100] = { 2,	TD|TFSF|TSFA,	SEN(fstatfs),			"fstatfs"		},
+[101] = { 2,	TF|TST|TSTA,	SEN(stat64),			"stat64"		},
 [102] = { },
 [103] = { 3,	0,		SEN(syslog),			"syslog"		},
 [104] = { 3,	0,		SEN(setitimer),			"setitimer"		},
@@ -114,7 +115,7 @@
 [109] = { 5,	TD,		SEN(pwrite),			"pwrite64"		},
 [110] = { 2,	TF,		SEN(getcwd),			"getcwd"		},
 [111] = { 0,	0,		SEN(vhangup),			"vhangup"		},
-[112] = { 2,	TD,		SEN(fstat64),			"fstat64"		},
+[112] = { 2,	TD|TFST|TSTA,	SEN(fstat64),			"fstat64"		},
 [113] = { 0,	TP,		SEN(vfork),			"vfork"			},
 [114] = { 4,	TP,		SEN(wait4),			"wait4"			},
 [115] = { 1,	TF,		SEN(swapoff),			"swapoff"		},
@@ -175,7 +176,7 @@
 [170] = { 3,	0,		SEN(setresgid),			"setresgid"		},
 [171] = { 3,	0,		SEN(getresgid),			"getresgid"		},
 [172] = { 5,	0,		SEN(prctl),			"prctl"			},
-[173] = { 0,	TS,		SEN(sigreturn),			"rt_sigreturn"		},
+[173] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [174] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
@@ -200,7 +201,7 @@
 [195] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
 [196] = { 5,	TN,		SEN(getpmsg),			"getpmsg"		},
 [197] = { 5,	TN,		SEN(putpmsg),			"putpmsg"		},
-[198] = { 2,	TF,		SEN(lstat64),			"lstat64"		},
+[198] = { 2,	TF|TLST|TSTA,	SEN(lstat64),			"lstat64"		},
 [199] = { 3,	TF,		SEN(truncate64),		"truncate64"		},
 [200] = { 3,	TD,		SEN(ftruncate64),		"ftruncate64"		},
 [201] = { 3,	TD,		SEN(getdents64),		"getdents64"		},
@@ -282,7 +283,7 @@
 [277] = { 4,	TD|TF,		SEN(mknodat),			"mknodat"		},
 [278] = { 5,	TD|TF,		SEN(fchownat),			"fchownat"		},
 [279] = { 3,	TD|TF,		SEN(futimesat),			"futimesat"		},
-[280] = { 4,	TD|TF,		SEN(fstatat64),			"fstatat64"		},
+[280] = { 4,	TD|TF|TFST|TSTA,SEN(fstatat64),			"fstatat64"		},
 [281] = { 3,	TD|TF,		SEN(unlinkat),			"unlinkat"		},
 [282] = { 4,	TD|TF,		SEN(renameat),			"renameat"		},
 [283] = { 5,	TD|TF,		SEN(linkat),			"linkat"		},
@@ -300,8 +301,8 @@
 [295] = { 6,	TM,		SEN(move_pages),		"move_pages"		},
 [296] = { 3,	0,		SEN(getcpu),			"getcpu"		},
 [297] = { 6,	TD,		SEN(epoll_pwait),		"epoll_pwait"		},
-[298] = { 3,	TF,		SEN(statfs64),			"statfs64"		},
-[299] = { 3,	TD,		SEN(fstatfs64),			"fstatfs64"		},
+[298] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
+[299] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
 [300] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
 [301] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
 [302] = { 3,	TD|TS,		SEN(signalfd),			"signalfd"		},
