@@ -6,9 +6,5 @@ get_error(struct tcb *tcp, const bool check_errno)
 		tcp->u_error = mips_REG_V0;
 	} else {
 		tcp->u_rval = mips_REG_V0;
-#ifdef LINUX_MIPSN32
-		/* tcp->u_rval contains a truncated value */
-		tcp->u_lrval = mips_REG_V0;
-#endif
 	}
 }
