@@ -4,9 +4,9 @@
 [6001] = { 3,	TD,		SEN(write),			"write"			},
 [6002] = { 3,	TD|TF,		SEN(open),			"open"			},
 [6003] = { 1,	TD,		SEN(close),			"close"			},
-[6004] = { 2,	TF,		SEN(stat64),			"stat"			},
-[6005] = { 2,	TD,		SEN(fstat64),			"fstat"			},
-[6006] = { 2,	TF,		SEN(lstat64),			"lstat"			},
+[6004] = { 2,	TF|TST|TSTA,	SEN(stat64),			"stat"			},
+[6005] = { 2,	TD|TFST|TSTA,	SEN(fstat64),			"fstat"			},
+[6006] = { 2,	TF|TLST|TSTA,	SEN(lstat64),			"lstat"			},
 [6007] = { 3,	TD,		SEN(poll),			"poll"			},
 [6008] = { 3,	TD,		SEN(lseek),			"lseek"			},
 [6009] = { 6,	TD|TM|SI,	SEN(mmap),			"mmap"			},
@@ -133,9 +133,9 @@
 [6130] = { 2,	TF,		SEN(utime),			"utime"			},
 [6131] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [6132] = { 1,	NF,		SEN(personality),		"personality"		},
-[6133] = { 2,	0,		SEN(ustat),			"ustat"			},
-[6134] = { 2,	TF,		SEN(statfs),			"statfs"		},
-[6135] = { 2,	TD,		SEN(fstatfs),			"fstatfs"		},
+[6133] = { 2,	TSFA,		SEN(ustat),			"ustat"			},
+[6134] = { 2,	TF|TSF|TSFA,	SEN(statfs),			"statfs"		},
+[6135] = { 2,	TD|TFSF|TSFA,	SEN(fstatfs),			"fstatfs"		},
 [6136] = { 3,	0,		SEN(sysfs),			"sysfs"			},
 [6137] = { 2,	0,		SEN(getpriority),		"getpriority"		},
 [6138] = { 3,	0,		SEN(setpriority),		"setpriority"		},
@@ -217,8 +217,8 @@
 [6214] = { 0,	0,		SEN(restart_syscall),		"restart_syscall"	},
 [6215] = { 4,	TI,		SEN(semtimedop),		"semtimedop"		},
 [6216] = { 4,	TD,		SEN(fadvise64_64),		"fadvise64"		},
-[6217] = { 3,	TF,		SEN(statfs64),			"statfs64"		},
-[6218] = { 3,	TD,		SEN(fstatfs64),			"fstatfs64"		},
+[6217] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
+[6218] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
 [6219] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [6220] = { 3,	0,		SEN(timer_create),		"timer_create"		},
 [6221] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
@@ -256,7 +256,7 @@
 [6253] = { 4,	TD|TF,		SEN(mknodat),			"mknodat"		},
 [6254] = { 5,	TD|TF,		SEN(fchownat),			"fchownat"		},
 [6255] = { 3,	TD|TF,		SEN(futimesat),			"futimesat"		},
-[6256] = { 4,	TD|TF,		SEN(newfstatat),		"newfstatat"		},
+[6256] = { 4,	TD|TF|TFST|TSTA,SEN(newfstatat),		"newfstatat"		},
 [6257] = { 3,	TD|TF,		SEN(unlinkat),			"unlinkat"		},
 [6258] = { 4,	TD|TF,		SEN(renameat),			"renameat"		},
 [6259] = { 5,	TD|TF,		SEN(linkat),			"linkat"		},
@@ -330,6 +330,7 @@
 [6327] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [6328] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [6329] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
+[6330] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
 
 # define SYS_socket_subcall      6400
 # include "subcall.h"
