@@ -2,9 +2,9 @@
 [  1] = { 3,	TD,		SEN(write),			"write"			},
 [  2] = { 3,	TD|TF,		SEN(open),			"open"			},
 [  3] = { 1,	TD,		SEN(close),			"close"			},
-[  4] = { 2,	TF,		SEN(stat),			"stat"			},
-[  5] = { 2,	TD,		SEN(fstat),			"fstat"			},
-[  6] = { 2,	TF,		SEN(lstat),			"lstat"			},
+[  4] = { 2,	TF|TST|TSTA,	SEN(stat),			"stat"			},
+[  5] = { 2,	TD|TFST|TSTA,	SEN(fstat),			"fstat"			},
+[  6] = { 2,	TF|TLST|TSTA,	SEN(lstat),			"lstat"			},
 [  7] = { 3,	TD,		SEN(poll),			"poll"			},
 [  8] = { 3,	TD,		SEN(lseek),			"lseek"			},
 [  9] = { 6,	TD|TM|SI,	SEN(mmap),			"mmap"			},
@@ -13,7 +13,7 @@
 [ 12] = { 1,	TM|SI,		SEN(brk),			"brk"			},
 [ 13] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [ 14] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
-[ 15] = { 0,	TS,		SEN(sigreturn),			"rt_sigreturn"		},
+[ 15] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [ 16] = { 3,	TD,		SEN(ioctl),			"ioctl"			},
 [ 17] = { 4,	TD,		SEN(pread),			"pread64"		},
 [ 18] = { 4,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -134,9 +134,9 @@
 [133] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [134] = { 1,	TF,		SEN(uselib),			"uselib"		},
 [135] = { 1,	NF,		SEN(personality),		"personality"		},
-[136] = { 2,	0,		SEN(ustat),			"ustat"			},
-[137] = { 2,	TF,		SEN(statfs),			"statfs"		},
-[138] = { 2,	TD,		SEN(fstatfs),			"fstatfs"		},
+[136] = { 2,	TSFA,		SEN(ustat),			"ustat"			},
+[137] = { 2,	TF|TSF|TSFA,	SEN(statfs),			"statfs"		},
+[138] = { 2,	TD|TFSF|TSFA,	SEN(fstatfs),			"fstatfs"		},
 [139] = { 3,	0,		SEN(sysfs),			"sysfs"			},
 [140] = { 2,	0,		SEN(getpriority),		"getpriority"		},
 [141] = { 3,	0,		SEN(setpriority),		"setpriority"		},
@@ -260,7 +260,7 @@
 [259] = { 4,	TD|TF,		SEN(mknodat),			"mknodat"		},
 [260] = { 5,	TD|TF,		SEN(fchownat),			"fchownat"		},
 [261] = { 3,	TD|TF,		SEN(futimesat),			"futimesat"		},
-[262] = { 4,	TD|TF,		SEN(newfstatat),		"newfstatat"		},
+[262] = { 4,	TD|TF|TFST|TSTA,SEN(newfstatat),		"newfstatat"		},
 [263] = { 3,	TD|TF,		SEN(unlinkat),			"unlinkat"		},
 [264] = { 4,	TD|TF,		SEN(renameat),			"renameat"		},
 [265] = { 5,	TD|TF,		SEN(linkat),			"linkat"		},
@@ -330,3 +330,4 @@
 [329] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [330] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [331] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
+[332] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
