@@ -1,6 +1,7 @@
 /*
  * Copyright (c) 2003-2007 Ulrich Drepper <drepper@redhat.com>
  * Copyright (c) 2005-2016 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2017 The strace developers.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -142,7 +143,7 @@ print_status(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
 	const int status = * (int *) elem_buf;
 
 	if (status < 0 && (unsigned) -status < nerrnos)
-		tprintf("%s", errnoent[-status]);
+		tprintf("-%s", errnoent[-status]);
 	else
 		tprintf("%d", status);
 
