@@ -2,6 +2,7 @@
  * Check decoding of getcpu syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
+ * Copyright (c) 2016-2017 The strace developers.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,8 +48,8 @@ main(void)
 		(unsigned *) tail_alloc(sizeof(* bogus_tcache)) + 1;
 
 	long res;
-	unsigned *cpu = tail_alloc(sizeof(*cpu));
-	unsigned *node = tail_alloc(sizeof(*node));
+	TAIL_ALLOC_OBJECT_CONST_PTR(unsigned, cpu);
+	TAIL_ALLOC_OBJECT_CONST_PTR(unsigned, node);
 	long * tcache = tail_alloc(128);
 
 	res = syscall(__NR_getcpu, NULL, NULL, NULL);
