@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2017 The strace developers.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +27,7 @@
  */
 
 #include "tests.h"
-#include <sys/syscall.h>
+#include <asm/unistd.h>
 
 #ifdef __NR_getdents64
 
@@ -98,12 +99,10 @@ print_dirent(const kernel_dirent64 *d)
 }
 
 int
-main(int ac, const char **av)
+main(void)
 {
-	char *dname;
+	static const char dname[] = "getdents64.test.tmp.dir";
 
-	assert(ac == 1);
-	assert(asprintf(&dname, "%s.test.tmp.dir", av[0]) > 0);
 	assert(!mkdir(dname, 0700));
 	assert(!chdir(dname));
 	(void) close(0);
@@ -111,12 +110,13 @@ main(int ac, const char **av)
 	assert(!close(0));
 	assert(!open(".", O_RDONLY | O_DIRECTORY));
 
-	unsigned long count = (unsigned long) 0xfacefeeddeadbeef;
-	long rc = syscall(__NR_getdents64, (long) 0xdefacedffffffff, NULL, count);
+	unsigned long count = (unsigned long) 0xfacefeeddeadbeefULL;
+	long rc = syscall(__NR_getdents64, (long) 0xdefacedffffffffULL, NULL,
+			  count);
 	printf("getdents64(-1, NULL, %u) = %ld %s (%m)\n",
 	       (unsigned) count, rc, errno2name());
 
-	count = (unsigned long) 0xfacefeed00000000 | sizeof(buf);
+	count = (unsigned long) 0xfacefeed00000000ULL | sizeof(buf);
 	while ((rc = syscall(__NR_getdents64, 0, buf, count))) {
 		kernel_dirent64 *d;
 		long i;
